==> advert-1.1.2-sources.jar: com/yodo1/plugin/dmp/yodo1/constants/AnalyticsConst.java <==
package com.yodo1.plugin.dmp.yodo1.constants;

/**
 * Created by zhuxiaochen on 2017/9/2.
 */
public class AnalyticsConst {

    //插屏
    public static final String InterstitialAdInit = "InterstitialAdInit";
    public static final String InterstitialAdInitChannel = "InterstitialAdInitChannel";
    public static final String InterstitialAdReload = "InterstitialAdReload";//争议，外部不会调用请求广告接口  内部调用时必定指定advertCode
    public static final String InterstitialAdReloadChannel = "InterstitialAdReloadChannel";
    public static final String InterstitialAdReloadResultChannel = "InterstitialAdReloadResultChannel";
    public static final String InterstitialAdShow = "InterstitialAdShow";
    public static final String InterstitialAdShowChannel = "InterstitialAdShowChannel";
    public static final String InterstitialAdShowResultChannel = "InterstitialAdShowResultChannel";


    //视频
    public static final String VideoAdInit = "VideoAdInit";
    public static final String VideoAdInitChannel = "VideoAdInitChannel";
    public static final String VideoAdReload = "VideoAdReload";//争议，外部不会调用请求广告接口  内部调用时必定指定advertCode
    public static final String VideoAdReloadChannel = "VideoAdReloadChannel";
    public static final String VideoAdReloadResultChannel = "VideoAdReloadResultChannel";
    public static final String VideoAdShow = "VideoAdShow";
    public static final String VideoAdShowChannel = "VideoAdShowChannel";
    public static final String VideoAdShowResultChannel = "VideoAdShowResultChannel";


    //Banner
    public static final String BannerAdInit = "BannerAdInit";
    public static final String BannerAdInitChannel = "BannerAdInitChannel";
    public static final String BannerAdReloadChannel = "BannerAdReloadChannel";//争议，外部不会调用请求广告接口  内部调用时必定指定advertCode
    public static final String BannerAdReloadResultChannel = "BannerAdReloadResultChannel";
    public static final String BannerAdShow = "BannerAdShow";
    public static final String BannerAdShowChannel = "BannerAdShowChannel";
    public static final String BannerAdClickChannel = "BannerAdClickChannel";

    public static final String AdvertCode = "AdvertCode";
    public static final String Result = "Result";


    public static final String ShowResulet_success= "success";
    public static final String ShowResulet_click = "click";
    public static final String ShowResulet_close = "close";
    public static final String ShowResulet_finish = "finish";
    public static final String ShowResulet_failed = "fail";


    public static final String ReloadResulet_finish = "finish";
    public static final String ReloadResulet_failed = "fail";


    //需求 是否统计展示或者请求广告时的失败原因

}

==> advert-1.4.7-sources.jar: com/yodo1/plugin/dmp/yodo1/constants/AnalyticsConst.java <==
package com.yodo1.plugin.dmp.yodo1.constants;

/**
 * Created by zhuxiaochen on 2017/9/2.
 */
public class AnalyticsConst {

    //插屏
    public static final String InterstitialAdInit = "InterstitialAdInit";
    public static final String InterstitialAdInitChannel = "InterstitialAdInitChannel";
    public static final String InterstitialAdReload = "InterstitialAdReload";//争议，外部不会调用请求广告接口  内部调用时必定指定advertCode
    public static final String InterstitialAdReloadChannel = "InterstitialAdReloadChannel";
    public static final String InterstitialAdReloadResultChannel = "InterstitialAdReloadResultChannel";
    public static final String InterstitialAdShow = "InterstitialAdShow";
    public static final String InterstitialAdShowChannel = "InterstitialAdShowChannel";
    public static final String InterstitialAdShowResultChannel = "InterstitialAdShowResultChannel";


    //视频
    public static final String VideoAdInit = "VideoAdInit";
    public static final String VideoAdInitChannel = "VideoAdInitChannel";
    public static final String VideoAdReload = "VideoAdReload";//争议，外部不会调用请求广告接口  内部调用时必定指定advertCode
    public static final String VideoAdReloadChannel = "VideoAdReloadChannel";
    public static final String VideoAdReloadResultChannel = "VideoAdReloadResultChannel";
    public static final String VideoAdShow = "VideoAdShow";
    public static final String VideoAdShowChannel = "VideoAdShowChannel";
    public static final String VideoAdShowResultChannel = "VideoAdShowResultChannel";


    //Banner
    public static final String BannerAdInit = "BannerAdInit";
    public static final String BannerAdInitChannel = "BannerAdInitChannel";
    public static final String BannerAdReloadChannel = "BannerAdReloadChannel";//争议，外部不会调用请求广告接口  内部调用时必定指定advertCode
    public static final String BannerAdReloadResultChannel = "BannerAdReloadResultChannel";
    public static final String BannerAdShow = "BannerAdShow";
    public static final String BannerAdShowChannel = "BannerAdShowChannel";
    public static final String BannerAdClickChannel = "BannerAdClickChannel";

    public static final String AdvertCode = "AdvertCode";
    public static final String Result = "Result";


    public static final String ShowResulet_success= "success";
    public static final String ShowResulet_click = "click";
    public static final String ShowResulet_close = "close";
    public static final String ShowResulet_finish = "finish";
    public static final String ShowResulet_failed = "fail";


    public static final String ReloadResulet_finish = "success";
    public static final String ReloadResulet_failed = "fail";


    //需求 是否统计展示或者请求广告时的失败原因

}
